@@ -1,4 +1,3 @@
-// $Id: backup_migrate.js,v 1.1.2.1.2.6 2010/03/24 04:02:58 ronan Exp $
 
 Drupal.backup_migrate = {
   callbackURL : "",  
@@ -19,38 +18,39 @@ Drupal.backup_migrate = {
           $("div.backup-migrate-save-options").slideDown('slow');
         }
       });
-  
-      $('#edit-filters-exclude-tables').after('<div class="description backup-migrate-checkbox-link"><a href="javascript:Drupal.backup_migrate.selectToCheckboxes(\''+ 'exclude_tables' +'\');">'+ Drupal.settings.backup_migrate.checkboxLinkText +'</a></div>');
-      $('#edit-filters-nodata-tables').after('<div class="description backup-migrate-checkbox-link"><a href="javascript:Drupal.backup_migrate.selectToCheckboxes(\''+ 'nodata_tables' +'\');">'+ Drupal.settings.backup_migrate.checkboxLinkText +'</a></div>');
+
+      $('select[multiple]').each(function() {
+          $(this).after(
+            $('<div class="description backup-migrate-checkbox-link"></div>').append(
+              $('<a href="javascript:null;"></a>').text(Drupal.settings.backup_migrate.checkboxLinkText).click(function() {
+                Drupal.backup_migrate.selectToCheckboxes($(this).parents('.form-item').find('select'));
+              })
+            )
+          );
+        }
+      );
     }
   },
 
-  processCheckboxes : function(ctxt) {
-    $("input.backup-migrate-tables-checkbox", ctxt).each(function() {
-      this.do_click = function() {
+  selectToCheckboxes : function($select) {
+    var field_id = $select.attr('id');
+    var $checkboxes = $('<div></div>').addClass('backup-migrate-tables-checkboxes');
+    $('option', $select).each(function(i) {
+      var self = this;
+      $box = $('<input type="checkbox" class="backup-migrate-tables-checkbox">').bind('change click', function() {
+        $select.find('option[value="'+self.value+'"]').attr('selected', this.checked);
         if (this.checked) {
           $(this).parent().addClass('checked');
         }
         else {
           $(this).parent().removeClass('checked');
         }
-      };
-      $(this).bind("click", function() { this.do_click() });
-      this.do_click();
-    });
-  },
-
-  selectToCheckboxes : function(field) {
-    var field_id = 'edit-filters-'+ field.replace('_', '-') ;
-    var $select = $('#'+ field_id);
-    var $checkboxes = $('<div></div>').addClass('backup-migrate-tables-checkboxes');
-    $('option', $select).each(function(i) {
-      $checkboxes.append('<div class="form-item"><label class="option backup-migrate-table-select"><input type="checkbox" class="backup-migrate-tables-checkbox" id="edit-'+ field_id +'-'+ this.value +'" name="'+ $select.attr('name') +'"'+ (this.selected ? 'checked="checked"' : '') +' value="'+ this.value +'"/>'+this.value+'</label></div>');
+      }).attr('checked', this.selected ? 'checked' : '');
+      $checkboxes.append($('<div class="form-item"></div>').append($('<label class="option backup-migrate-table-select">'+this.value+'</label>').prepend($box)));
     });
     $select.parent().find('.backup-migrate-checkbox-link').remove();
     $select.before($checkboxes);
     $select.hide();
-    Drupal.backup_migrate.processCheckboxes($checkboxes);
   }
 }
 
